Новости
=======

Version 0.1.2 (2018-05-22)
--------------------------

* Исправлен импорт INPX: сделано декодирование имён файлов в юникод.

Version 0.1.1 (2018-05-17)
--------------------------

* Импортируются все файлы \*.glst (Flibusta fb2, LibRusEc fb2, non-fb2).

* Файл README.txt конвертирован в README.rst.

* Импортируются новые INP Флибусты (17 полей).

Version 0.1.0 (2018-04-25)
--------------------------

* Web-интерфейс для поиска авторов, показа списка книг автора,
  загрузки одной книги.

* Программа `ml-web.py` не позволяет запускать два экземпляра.
  Второй экземпляр перенаправляет web-обозреватель на web-интерфейс
  первого экземпляра и прекращает работу.

* Опция `--download-to` в скрипте `ml-search.py` задаёт директорию
  для сохранения книг.
